/*
 * National Instruments NAT4882 GPIB interface chip definitions
 * Copyright (C) 1995  W. Eric Norum
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 * W. Eric Norum
 * Saskatchewan Accelerator Laboratory
 * University of Saskatchewan
 * 107 North Road
 * Saskatoon, Saskatchewan, CANADA
 * S7N 5C6
 * 
 * eric@skatter.usask.ca
 */

/*
 * Input registers
 */
#define NAT4882_DIR			0
#define NAT4882_ISR1		1
#define NAT4882_ISR2		2
#define NAT4882_SPSR		3
#define NAT4882_KSR_PAGED	3
#define NAT4882_ADSR		4
#define NAT4882_CPTR		5
#define NAT4882_SASR_PAGED	5
#define NAT4882_ADR0		6
#define NAT4882_ISR0_PAGED	6
#define NAT4882_ADR1		7
#define NAT4882_BSR_PAGED	7

/*
 * Output registers
 */
#define NAT4882_CDOR		0
#define NAT4882_IMR1		1
#define NAT4882_IMR2		2
#define NAT4882_KCR_PAGED	3
#define NAT4882_SPMR		3
#define NAT4882_ADMR		4
#define NAT4882_AUXMR		5
#define NAT4882_IMR0_PAGED	6
#define NAT4882_ADR			6
#define NAT4882_BCR_PAGED	7
#define NAT4882_EOSR		7

/*
 * Interrupt Status Registers
 */
#define NAT4882_ISR0_cdba		0x80	/* Command/Data Byte Available */
#define NAT4882_ISR0_STBO		0x40	/* Status Byte Out */
#define NAT4882_ISR0_NL			0x20	/* Newline received */
#define NAT4882_ISR0_EOS		0x10	/* End Of String received */
#define NAT4882_ISR0_IFC		0x08	/* IFC* has been asserted */
#define NAT4882_ISR0_ATNI		0x04	/* ATN* has been asserted */
#define NAT4882_ISR0_TO			0x02	/* Timeout has occurred */
#define NAT4882_ISR0_SYNC		0x01	/* GPIB synchronization has completed */

#define NAT4882_ISR1_CPT		0x80	/* Command Pass Through */
#define NAT4882_ISR1_APT		0x40	/* Address Pass Through */
#define NAT4882_ISR1_DET		0x20	/* Device Trigger */
#define NAT4882_ISR1_END		0x10	/* Data Block End (EOI or EOS) */
#define NAT4882_ISR1_DEC		0x08	/* Device Clear */
#define NAT4882_ISR1_ERR		0x04	/* Error (Byte Out data lost) */
#define NAT4882_ISR1_DO			0x02	/* Byte Out Register Ready */
#define NAT4882_ISR1_DI			0x01	/* Data In Register Ready */

#define NAT4882_ISR2_INT		0x80	/* Interrupt Pin */
#define NAT4882_ISR2_SRQI		0x40	/* Service Request */
#define NAT4882_ISR2_LOK		0x20	/* Lockout state (non interrupt) */
#define NAT4882_ISR2_REM		0x10	/* Remote state (non interrupt) */
#define NAT4882_ISR2_CO			0x08	/* Command Output ready */
#define NAT4882_ISR2_LOKC		0x04	/* Lockout state change */
#define NAT4882_ISR2_REMC		0x02	/* Remote state change */
#define NAT4882_ISR2_ADSC		0x01	/* Address status change

/*
 * Interrupt Mask Registers
 */
#define NAT4882_IMR0_GLINT		0x80	/* Global interrupt enable */
#define NAT4882_IMR0_STBO_IE	0x40	/* Status Byte Out */
#define NAT4882_IMR0_NLEE		0x20	/* Newline End Enable */
#define NAT4882_IMR0_BTO		0x10	/* Byte Timeout enable */
#define NAT4882_IMR0_IFC_IE		0x08	/* IFC* has been asserted */
#define NAT4882_IMR0_ATNI_IE	0x04	/* ATN* has been asserted */
#define NAT4882_IMR0_TO_IE		0x02	/* Timeout has occurred */
#define NAT4882_IMR0_SYNC_IE	0x01	/* GPIB synchronization has completed */

#define NAT4882_IMR1_CPT_IE		0x80	/* Command Pass Through */
#define NAT4882_IMR1_APT_IE		0x40	/* Address Pass Through */
#define NAT4882_IMR1_DET_IE		0x20	/* Device Trigger */
#define NAT4882_IMR1_ENDRX_IE	0x10	/* Data Block End (EOI or EOS) */
#define NAT4882_IMR1_DEC_IE		0x08	/* Device Clear */
#define NAT4882_IMR1_ERR_IE		0x04	/* Error (Byte Out data lost) */
#define NAT4882_IMR1_DO_IE		0x02	/* Byte Out Register Ready */
#define NAT4882_IMR1_DI_IE		0x01	/* Data In Register Ready */

#define NAT4882_IMR2_SRQI_IE	0x40	/* Service Request */
#define NAT4882_IMR2_DMAO		0x20	/* Enable DMA output requests */
#define NAT4882_IMR2_DMAI		0x10	/* Enable DMA input requests */
#define NAT4882_IMR2_CO_IE		0x08	/* Command Output ready */
#define NAT4882_IMR2_LOKC_IE	0x04	/* Lockout state change */
#define NAT4882_IMR2_REMC_IE	0x02	/* Remote state change */
#define NAT4882_IMR2_ADSC_IE	0x01	/* Address status change

/*
 * Address Status Register
 */
#define NAT4882_ADSR_CIC		0x80	/* Controller In Charge */
#define NAT4882_ADSR_ATNBAR		0x40	/* Device in DATA mode (ATN not asserted) */
#define NAT4882_ADSR_SPMS		0x20	/* Device in SPMS state */
#define NAT4882_ADSR_LPAS		0x10	/* Device in LPAS state */
#define NAT4882_ADSR_TPAS		0x08	/* Device in TPAS state */
#define NAT4882_ADSR_LA			0x04	/* Device in LADS state */
#define NAT4882_ADSR_TA			0x02	/* Device in TADS state */
#define NAT4882_ADSR_MJMN		0x01	/* 1-minor address rcvd, 0-major */

/*
 * Address Mode Register
 */
#define NAT4882_ADMR_ton		0x80	/* Talk-only mode */
#define NAT4882_ADMR_lon		0x40	/* Listen-only mode */
#define NAT4882_ADMR_TRM1		0x20	/* T/R2,3 pin function mode bit 1 */
#define NAT4882_ADMR_TRM0		0x10	/* T/R2,3 pin function mode bit 0 */
#define NAT4882_ADMR_ADM1		0x02	/* Address mode bit 1 */
#define NAT4882_ADMR_ADM0		0x01	/* Address mode bit 0 */

/*
 * Address registers
 */
#define NAT4882_ADR0_DT0		0x40	/* Disable talker address */
#define NAT4882_ADR0_DL0		0x20	/* Disable listener address */
#define NAT4882_ADR0_AD5_0		0x10	/* Address register 0 bit 5 */
#define NAT4882_ADR0_AD4_0		0x08	/* Address register 0 bit 4 */
#define NAT4882_ADR0_AD3_0		0x04	/* Address register 0 bit 3 */
#define NAT4882_ADR0_AD2_0		0x02	/* Address register 0 bit 2 */
#define NAT4882_ADR0_AD1_0		0x01	/* Address register 0 bit 1 */

#define NAT4882_ADR1_EOI		0x80	/* State of EOI line */
#define NAT4882_ADR1_DT1		0x40	/* Disable talker address */
#define NAT4882_ADR1_DL1		0x20	/* Disable listener address */
#define NAT4882_ADR1_AD5_1		0x10	/* Address register 1 bit 5 */
#define NAT4882_ADR1_AD4_1		0x08	/* Address register 1 bit 4 */
#define NAT4882_ADR1_AD3_1		0x04	/* Address register 1 bit 3 */
#define NAT4882_ADR1_AD2_1		0x02	/* Address register 1 bit 2 */
#define NAT4882_ADR1_AD1_1		0x01	/* Address register 1 bit 1 */

#define NAT4882_ADR_ARS			0x80	/* Address Register Select */
#define NAT4882_ADR_DT			0x40	/* Disable talker address */
#define NAT4882_ADR_DL			0x20	/* Disable listener address */
#define NAT4882_ADR_AD5			0x10	/* Address bit 5 */
#define NAT4882_ADR_AD4			0x08	/* Address bit 4 */
#define NAT4882_ADR_AD3			0x04	/* Address bit 3 */
#define NAT4882_ADR_AD2			0x02	/* Address bit 2 */
#define NAT4882_ADR_AD1			0x01	/* Address bit 1 */

/*
 * Key Status Register
 */
#define NAT4882_KSR_VMASK		0xF0	/* Version number mask */
#define NAT4882_KSR_KEYDQ		0x08	/* Logic value of KEYDQ pin */
#define NAT4882_KSR_MODE		0x04	/* Logic value of MODE pin */

/*
 * Auxiliary Mode Register Commands
 */
#define NAT4882_AUXMR_PON		0x00		/* Execute power-on */
#define NAT4882_AUXMR_CR		0x02		/* Chip reset */
#define NAT4882_AUXMR_FHS		0x03		/* Finish Handshake */
#define NAT4882_AUXMR_TRIG		0x04		/* Trigger */
#define NAT4882_AUXMR_RTL		0x05		/* Return To Local pulse */
#define NAT4882_AUXMR_RTL_SET	0x0D		/* Return To Local */
#define NAT4882_AUXMR_SEOI		0x06		/* Send END with next data */
#define NAT4882_AUXMR_NVID		0x07		/* Finish APT, Other Secondary Address */
#define NAT4882_AUXMR_VID		0x0F		/* Finish APT, My Secondary Address */
#define NAT4882_AUXMR_REQCNTL	0x08		/* Request control */
#define NAT4882_AUXMR_CPP		0x01		/* Clear Parallel Poll Flag */
#define NAT4882_AUXMR_SPP		0x09		/* Set Parallel Poll Flag */
#define NAT4882_AUXMR_RLSCNTL	0x0A		/* Release control */
#define NAT4882_AUXMR_UNT		0x0B		/* Local UnTalk */
#define NAT4882_AUXMR_UNL		0x0C		/* Local UnListen */
#define NAT4882_AUXMR_NBAF		0x0E		/* New Byte Available False */
#define NAT4882_AUXMR_GTS		0x10		/* Go To Standby */
#define NAT4882_AUXMR_TCA		0x11		/* Take Control Asynchronously */
#define NAT4882_AUXMR_TCS		0x12		/* Take Control Synchronously */
#define NAT4882_AUXMR_TCSE		0x1A		/* TCS at end of data transfer */
#define NAT4882_AUXMR_LTN		0x13		/* Listen */
#define NAT4882_AUXMR_LTNC		0x1B		/* Listen in continuous mode */
#define NAT4882_AUXMR_LUN		0x1C		/* Local Unlisten */
#define NAT4882_AUXMR_DSC		0x14		/* Disable System Control */
#define NAT4882_AUXMR_9914A		0x15		/* Switch to 9914A mode */
#define NAT4882_AUXMR_SIFC		0x1E		/* Set IFC */
#define NAT4882_AUXMR_CIFC		0x16		/* Clear IFC */
#define NAT4882_AUXMR_SREN		0x1F		/* Set REN */
#define NAT4882_AUXMR_CREN		0x17		/* Clear REN */
#define NAT4882_AUXMR_REQT		0x18		/* Request rsv True */
#define NAT4882_AUXMR_REQF		0x19		/* Request rsv False */
#define NAT4882_AUXMR_EPP		0x1D		/* Execute Parallel Poll */

#define NAT4882_AUXMR_PAGEIN	0x50		/* Page-in additional registers */
#define NAT4882_AUXMR_IMH		0x51		/* Immediate Holdoff */
#define NAT4882_AUXMR_CLRDET	0x54		/* Clear DET (ISR1[5]) */
#define NAT4882_AUXMR_CLREND	0x55		/* Clear END (ISR1[4]) */
#define NAT4882_AUXMR_CLRDEC	0x56		/* Clear DEC (ISR1[3]) */
#define NAT4882_AUXMR_CLRERR	0x57		/* Clear ERR (ISR1[2]) */
#define NAT4882_AUXMR_CLRSRQI	0x58		/* Clear SRQI (ISR2[6]) */
#define NAT4882_AUXMR_CLRLOKC	0x59		/* Clear LOKC (ISR2[2]) */
#define NAT4882_AUXMR_CLRREMC	0x5A		/* Clear REMC (ISR2[1]) */
#define NAT4882_AUXMR_CLRADSC	0x5B		/* Clear ADSC (ISR2[0]) */
#define NAT4882_AUXMR_CLRIFCI	0x5C		/* Clear IFCI (ISR0[3]) */
#define NAT4882_AUXMR_CLRATNI	0x5D		/* Clear ATNI (ISR0[2]) */
#define NAT4882_AUXMR_CLRSYNC	0x5E		/* Clear SYNC */
#define NAT4882_AUXMR_SETSYNC	0x5F		/* Set SYNC */

/*
 * Auxiliary Mode Hidden Registers
 */
#define NAT4882_AUXMR_A(x)		(0x80|(x))	/* Auxiliary register A */
#define NAT4882_AUXMR_B(x)		(0xA0|(x))	/* Auxiliary register B */
#define NAT4882_AUXMR_E(x)		(0xC0|(x))	/* Auxiliary register E */
#define NAT4882_AUXMR_F(x)		(0xD0|(x))	/* Auxiliary register F */
#define NAT4882_AUXMR_G(x)		(0x40|(x))	/* Auxiliary register G */
#define NAT4882_AUXMR_I(x)		(0xE0|(x))	/* Auxiliary register I */
#define NAT4882_AUXMR_J(x)		(0xF0|(x))	/* Auxiliary register J */

/*
 * Auxiliary Mode Hidden Register Bits
 */
#define NAT4882_AUXRA_BIN		0x10		/* 8-bit EOS character	*/
#define NAT4882_AUXRA_XEOS		0x08		/* Transmit END with EOS */
#define NAT4882_AUXRA_REOS		0x04		/* Set END when EOS received */
#define NAT4882_AUXRA_HLDE		0x02		/* Holdoff on END */
#define NAT4882_AUXRA_HLDA		0x01		/* Holdoff always */

#define NAT4882_AUXRB_ISS		0x10		/* Individual status select bit */
#define NAT4882_AUXRB_INV		0x08		/* Invert polarity of INT pin */
#define NAT4882_AUXRB_TRI		0x04		/* Three-state buffer timing */
#define NAT4882_AUXRB_SPEIO		0x02		/* Send serial poll EOI */
#define NAT4882_AUXRB_CPTEN		0x01		/* Command pass-through enable */

#define NAT4882_AUXRE_DHADT		0x08		/* Holdoff on GET */
#define NAT4882_AUXRE_DHADC		0x04		/* Holdoff on DCL or SDC */
#define NAT4882_AUXRE_DHDT		0x02		/* Holdoff on DTAS */
#define NAT4882_AUXRE_DHDC		0x01		/* Holdoff on DCAS */

#define NAT4882_AUXRF_DHATA		0x08		/* Holdoff on Talker Addressed */
#define NAT4882_AUXRF_DHALA		0x04		/* Holdoff on Listener Addressed */
#define NAT4882_AUXRF_DHUNTL	0x02		/* Holdoff on UNT or UNL */
#define NAT4882_AUXRF_DHALL		0x01		/* Holdoff on UCG, ACG or SCG */

#define NAT4882_AUXRG_NTNL		0x08		/* No talking when no listener */
#define NAT4882_AUXRG_RPP2		0x04		/* Request parallel poll 2 */
#define NAT4882_AUXRG_DISTCT	0x02		/* Disable automatic take control */
#define NAT4882_AUXRG_CHES		0x01		/* Clear holdoff on END */

#define NAT4882_AUXRI_USTD		0x08		/* Ultra-short T1 delay */
#define NAT4882_AUXRI_PP2		0x04		/* Parallel poll 2 */
#define NAT4882_AUXRI_ACC		0x02		/* Automatic carry cycle */
#define NAT4882_AUXRI_SISB		0x01		/* Static interrupt status */
